import java.awt.*;
import java.awt.event.*;

public class MessageDialog extends Dialog implements ActionListener
{
  static final int WIDTH = 400;
  static final int HEIGHT = 110;

  public static final int NONE = 0x00;
  public static final int OK = 0x01;
  public static final String OK_COMMAND = "ok";
  public static final int CANCEL = 0x02;
  public static final String CANCEL_COMMAND = "cancel";
  public static final int YES = 0x04;
  public static final String YES_COMMAND = "yes";
  public static final int NO = 0x08;
  public static final String NO_COMMAND = "no";
  public static final int OK_CANCEL = OK | CANCEL;
  public static final int YES_NO = YES | NO;

  private int result = NONE;
  private Label label = new Label();
  private Panel buttonPanel = new Panel();

  public MessageDialog(
    Frame parent,
    String title,
    String msg,
    int buttonSet)
  {
    super(parent, title, true);

    // Sets the message

    Panel panel = new Panel();
    panel.setLayout(new FlowLayout(FlowLayout.LEFT));
    label.setText(msg);
    panel.add(label);
    add("Center", panel);

    // Sets the buttons

    if ((OK & buttonSet) != 0)
      addButton("OK", OK_COMMAND); //ivde
    if ((CANCEL & buttonSet) != 0)
      addButton("Cancel", CANCEL_COMMAND); //ivde
    if ((YES & buttonSet) != 0)
      addButton("Yes", YES_COMMAND); //ivde
    if ((NO & buttonSet) != 0)
      addButton("No", NO_COMMAND); //ivde
    add("South", buttonPanel);

    // Sets the default size

    setSize(WIDTH, HEIGHT);
  }

  private void addButton(String text, String command)
  {
    Button button = new Button();

    button.setLabel(text);
    button.setActionCommand(command);
    button.addActionListener(this);
    buttonPanel.add(button);
  }

  public int getResult()
  {
    return result;
  }

  public void actionPerformed(ActionEvent e)
  {
    if (e.getActionCommand().equals(OK_COMMAND))
      result = OK;
    else if (e.getActionCommand().equals(CANCEL_COMMAND))
      result = CANCEL;
    else if (e.getActionCommand().equals(YES_COMMAND))
      result = YES;
    else if (e.getActionCommand().equals(NO_COMMAND))
      result = NO;

    if (result != NONE)
    {
      setVisible(false);
      dispose();
    }
  }

  /**
   * Displays a message box.
   * @param frame The parent frame for the message box. This can also be null.
   * @param title The title-bar text of the message box in the native language.
   * @param msg The message string to display in the message box in the native language.
   * @param buttonSet Any combination of button codes.
   * @return The code of the button that was pressed.
   */
  public static int messageBox(
    Frame frame,
    String title,
    String msg,
    int buttonSet)
  {
    Frame tempFrame = null;
    Dimension frameSize;
    Point loc;

    if (frame == null)
    {
      tempFrame = new Frame();
      frame = tempFrame;
      frameSize = Toolkit.getDefaultToolkit().getScreenSize();
      loc = new Point(0, 0);
    }
    else
    {
      frameSize = frame.getSize();
      loc = frame.getLocation();
    }

    MessageDialog dialog = new MessageDialog(frame, title, msg, buttonSet);
    //Dimension dialogSize = dialog.getPreferredSize();
    Dimension dialogSize = new Dimension(WIDTH, HEIGHT);

    dialog.setLocation(
      (frameSize.width - dialogSize.width)/2 + loc.x,
      (frameSize.height - dialogSize.height)/2 + loc.y);
    dialog.show();

    if (tempFrame != null)
      tempFrame.dispose();

    return dialog.getResult();
  }
}

